import { MultilineString } from '@jupyterlab/nbformat';
import { ICellModel } from '@jupyterlab/cells';
export declare const normalizeMultilineString: (source: MultilineString) => string[];
/**
 * Very hacky code snippets to check if a line could be a code statement.
 * This could go wrong in a lot of ways and will just work in the
 * most common use cases.
 *
 * Expected to return true for import and code blocks
 */
export declare const couldBeCode: (line: string) => boolean;
export declare const couldBeImportStatement: (line: string) => boolean;
/**
 * It is safe to insert import only if current line is empty or doesn't start with a whitespace
 * */
export declare const safeToinsertImport: (line: string) => boolean;
/**
 * Takes in a list of cell models and returns
 * the first *code* cell that
 *
 * - doesn't start with a line or cell magic
 *   (If it is line magic, should we inspect the following block of code?)
 * - isn't all import blocks and comments.
 *
 * @param cellModels - an array of cell models
 */
export declare const findCell: (cellModels: ICellModel[]) => number;
/**
 * Find the last import in a cell and return the position after that.
 *
 * If no imports exist, but code does, return 0.
 *
 * Else, it is likely an empty cell or a comment cell. Return -1.
 *
 * If we decide to reformat on each import, we can change this to
 * insert at the end of any code cell and just
 *
 * @param cell - a cell model
 */
export declare const findLinePos: (cell: ICellModel) => number;
